(quick-start)=
# Quick Start 

🚀 Get started with the following command:

```bash
pip install -U ragrank
```

If you’re planning to contribute and make modifications to the code 🥹, install from the source

```{important}
This library is using [uv](https://github.com/astral-sh/uv) for dependency management and packaging. If `uv` is not installed in your system, please refer this [installation guide](https://docs.astral.sh/uv/getting-started/installation/) and install `uv` 😊.
```

```bash
git clone https://github.com/Auto-Playground/ragrank.git
cd ragrank
uv sync
```

Now you can do the [evaluation](basic_evaluation.md) on your own. 
